@@ -1,3 +1,6 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+# flake8: noqa
+
 # Copyright 2013 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,8 +15,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-# NOTE(notmorgan): Be careful in adjusting whitespace here, flake8 checks
-# get cranky.
-from keystone.auth import core  # noqa
-
-from keystone.auth import controllers  # noqa
+from keystone.auth import controllers
+from keystone.auth.core import *
+from keystone.auth import routers
