@@ -1,6 +1,6 @@
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 
-# Copyright 2013 OpenStack LLC
+# Copyright 2013 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,18 +14,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import json
 
-from keystone.auth import token_factory
 from keystone.common import controller
-from keystone.common import cms
-from keystone.common import logging
+from keystone.common import dependency
+from keystone.common import wsgi
 from keystone import config
 from keystone import exception
 from keystone import identity
+from keystone.openstack.common import importutils
+from keystone.openstack.common import log as logging
 from keystone import token
 from keystone import trust
-from keystone.openstack.common import importutils
 
 
 LOG = logging.getLogger(__name__)
@@ -51,7 +50,7 @@ def get_auth_method(method_name):
 
 
 class AuthInfo(object):
-    """ Encapsulation of "auth" request. """
+    """Encapsulation of "auth" request."""
 
     def __init__(self, context, auth=None):
         self.identity_api = identity.Manager()
@@ -94,11 +93,9 @@ class AuthInfo(object):
                                             target='domain')
         try:
             if domain_name:
-                domain_ref = self.identity_api.get_domain_by_name(
-                    context=self.context, domain_name=domain_name)
+                domain_ref = self.identity_api.get_domain_by_name(domain_name)
             else:
-                domain_ref = self.identity_api.get_domain(
-                    context=self.context, domain_id=domain_id)
+                domain_ref = self.identity_api.get_domain(domain_id)
         except exception.DomainNotFound as e:
             LOG.exception(e)
             raise exception.Unauthorized(e)
@@ -119,11 +116,9 @@ class AuthInfo(object):
                                                     target='project')
                 domain_ref = self._lookup_domain(project_info['domain'])
                 project_ref = self.identity_api.get_project_by_name(
-                    context=self.context, tenant_name=project_name,
-                    domain_id=domain_ref['id'])
+                    project_name, domain_ref['id'])
             else:
-                project_ref = self.identity_api.get_project(
-                    context=self.context, tenant_id=project_id)
+                project_ref = self.identity_api.get_project(project_id)
         except exception.ProjectNotFound as e:
             LOG.exception(e)
             raise exception.Unauthorized(e)
@@ -135,7 +130,7 @@ class AuthInfo(object):
         if not trust_id:
             raise exception.ValidationError(attribute='trust_id',
                                             target='trust')
-        trust = self.trust_api.get_trust(self.context, trust_id)
+        trust = self.trust_api.get_trust(trust_id)
         if not trust:
             raise exception.TrustNotFound(trust_id=trust_id)
         return trust
@@ -154,11 +149,9 @@ class AuthInfo(object):
                                                     target='user')
                 domain_ref = self._lookup_domain(user_info['domain'])
                 user_ref = self.identity_api.get_user_by_name(
-                    context=self.context, user_name=user_name,
-                    domain_id=domain_ref['id'])
+                    user_name, domain_ref['id'])
             else:
-                user_ref = self.identity_api.get_user(
-                    context=self.context, user_id=user_id)
+                user_ref = self.identity_api.get_user(user_id)
         except exception.UserNotFound as e:
             LOG.exception(e)
             raise exception.Unauthorized(e)
@@ -166,7 +159,7 @@ class AuthInfo(object):
         return user_ref
 
     def _validate_and_normalize_scope_data(self):
-        """ Validate and normalize scope data """
+        """Validate and normalize scope data."""
         if 'scope' not in self.auth:
             return
         if sum(['project' in self.auth['scope'],
@@ -187,7 +180,7 @@ class AuthInfo(object):
                 raise exception.Forbidden('Trusts are disabled.')
             trust_ref = self._lookup_trust(
                 self.auth['scope']['OS-TRUST:trust'])
-            #TODO ayoung when trusts support domain, Fill in domain data here
+            # TODO(ayoung): when trusts support domains, fill in domain data
             if 'project_id' in trust_ref:
                 project_ref = self._lookup_project(
                     {'id': trust_ref['project_id']})
@@ -196,6 +189,10 @@ class AuthInfo(object):
                 self._scope_data = (None, None, trust_ref)
 
     def _validate_auth_methods(self):
+        if 'identity' not in self.auth:
+            raise exception.ValidationError(attribute='identity',
+                                            target='auth')
+
         # make sure auth methods are provided
         if 'methods' not in self.auth['identity']:
             raise exception.ValidationError(attribute='methods',
@@ -213,7 +210,7 @@ class AuthInfo(object):
                 raise exception.AuthMethodNotSupported()
 
     def _validate_and_normalize_auth_data(self):
-        """ Make sure "auth" is valid. """
+        """Make sure "auth" is valid."""
         # make sure "auth" exist
         if not self.auth:
             raise exception.ValidationError(attribute='auth',
@@ -223,33 +220,33 @@ class AuthInfo(object):
         self._validate_and_normalize_scope_data()
 
     def get_method_names(self):
-        """ Returns the identity method names.
+        """Returns the identity method names.
 
         :returns: list of auth method names
 
         """
-        return self.auth['identity']['methods']
+        return self.auth['identity']['methods'] or []
 
     def get_method_data(self, method):
-        """ Get the auth method payload.
+        """Get the auth method payload.
 
         :returns: auth method payload
 
         """
         if method not in self.auth['identity']['methods']:
-            raise exception.ValidationError(attribute=method_name,
+            raise exception.ValidationError(attribute=method,
                                             target='identity')
         return self.auth['identity'][method]
 
     def get_scope(self):
-        """ Get scope information.
+        """Get scope information.
 
         Verify and return the scoping information.
 
         :returns: (domain_id, project_id, trust_ref).
                    If scope to a project, (None, project_id, None)
                    will be returned.
-                   If scoped to a domain, (domain_id, None,None)
+                   If scoped to a domain, (domain_id, None, None)
                    will be returned.
                    If scoped to a trust, (None, project_id, trust_ref),
                    Will be returned, where the project_id comes from the
@@ -260,7 +257,7 @@ class AuthInfo(object):
         return self._scope_data
 
     def set_scope(self, domain_id=None, project_id=None, trust=None):
-        """ Set scope information. """
+        """Set scope information."""
         if domain_id and project_id:
             msg = _('Scoping to both domain and project is not allowed')
             raise ValueError(msg)
@@ -273,6 +270,7 @@ class AuthInfo(object):
         self._scope_data = (domain_id, project_id, trust)
 
 
+@dependency.requires('token_provider_api')
 class Auth(controller.V3Controller):
     def __init__(self, *args, **kw):
         super(Auth, self).__init__(*args, **kw)
@@ -280,24 +278,36 @@ class Auth(controller.V3Controller):
         config.setup_authentication()
 
     def authenticate_for_token(self, context, auth=None):
-        """ Authenticate user and issue a token. """
+        """Authenticate user and issue a token."""
+        include_catalog = 'nocatalog' not in context['query_string']
+
         try:
             auth_info = AuthInfo(context, auth=auth)
-            auth_context = {'extras': {}, 'method_names': []}
+            auth_context = {'extras': {}, 'method_names': [], 'bind': {}}
             self.authenticate(context, auth_info, auth_context)
-            self._check_and_set_default_scoping(context, auth_info,
-                                                auth_context)
-            (token_id, token_data) = token_factory.create_token(
-                context, auth_context, auth_info)
-            return token_factory.render_token_data_response(
-                token_id, token_data, created=True)
-        except exception.SecurityError:
-            raise
-        except Exception as e:
-            LOG.exception(e)
+            if auth_context.get('access_token_id'):
+                auth_info.set_scope(None, auth_context['project_id'], None)
+            self._check_and_set_default_scoping(auth_info, auth_context)
+            (domain_id, project_id, trust) = auth_info.get_scope()
+            method_names = auth_info.get_method_names()
+            method_names += auth_context.get('method_names', [])
+            # make sure the list is unique
+            method_names = list(set(method_names))
+            expires_at = auth_context.get('expires_at')
+            # NOTE(morganfainberg): define this here so it is clear what the
+            # argument is during the issue_v3_token provider call.
+            metadata_ref = None
+
+            (token_id, token_data) = self.token_provider_api.issue_v3_token(
+                auth_context['user_id'], method_names, expires_at, project_id,
+                domain_id, auth_context, trust, metadata_ref, include_catalog)
+
+            return render_token_data_response(token_id, token_data,
+                                              created=True)
+        except exception.TrustNotFound as e:
             raise exception.Unauthorized(e)
 
-    def _check_and_set_default_scoping(self, context, auth_info, auth_context):
+    def _check_and_set_default_scoping(self, auth_info, auth_context):
         (domain_id, project_id, trust) = auth_info.get_scope()
         if trust:
             project_id = trust['project_id']
@@ -307,8 +317,7 @@ class Auth(controller.V3Controller):
 
         # fill in default_project_id if it is available
         try:
-            user_ref = self.identity_api.get_user(
-                context=context, user_id=auth_context['user_id'])
+            user_ref = self.identity_api.get_user(auth_context['user_id'])
             default_project_id = user_ref.get('default_project_id')
             if default_project_id:
                 auth_info.set_scope(domain_id=None,
@@ -317,31 +326,13 @@ class Auth(controller.V3Controller):
             LOG.exception(e)
             raise exception.Unauthorized(e)
 
-    def _build_remote_user_auth_context(self, context, auth_info,
-                                        auth_context):
-        username = context['REMOTE_USER']
-        # FIXME(gyee): REMOTE_USER is not good enough since we are
-        # requiring domain_id to do user lookup now. Try to get
-        # the user_id from auth_info for now, assuming external auth
-        # has check to make sure user is the same as the one specify
-        # in "identity".
-        if 'password' in auth_info.get_method_names():
-            user_info = auth_info.get_method_data('password')
-            user_ref = auth_info.lookup_user(user_info['user'])
-            auth_context['user_id'] = user_ref['id']
-        else:
-            msg = _('Unable to lookup user %s') % (username)
-            raise exception.Unauthorized(msg)
-
     def authenticate(self, context, auth_info, auth_context):
-        """ Authenticate user. """
+        """Authenticate user."""
 
-        # user have been authenticated externally
+        # user has been authenticated externally
         if 'REMOTE_USER' in context:
-            self._build_remote_user_auth_context(context,
-                                                 auth_info,
-                                                 auth_context)
-            return
+            external = get_auth_method('external')
+            external.authenticate(context, auth_info, auth_context)
 
         # need to aggregate the results in case two or more methods
         # are specified
@@ -363,46 +354,41 @@ class Auth(controller.V3Controller):
             msg = _('User not found')
             raise exception.Unauthorized(msg)
 
-    def _get_token_ref(self, context, token_id, belongs_to=None):
-        token_ref = self.token_api.get_token(context=context,
-                                             token_id=token_id)
-        if cms.is_ans1_token(token_id):
-            verified_token = cms.cms_verify(cms.token_to_cms(token_id),
-                                            CONF.signing.certfile,
-                                            CONF.signing.ca_certs)
-            token_ref = json.loads(verified_token)
-        if belongs_to:
-            assert token_ref['project']['id'] == belongs_to
-        return token_ref
-
-    @controller.protected
+    @controller.protected()
     def check_token(self, context):
-        try:
-            token_id = context.get('subject_token_id')
-            belongs_to = context['query_string'].get('belongsTo')
-            assert self._get_token_ref(context, token_id, belongs_to)
-        except Exception as e:
-            LOG.error(e)
-            raise exception.Unauthorized(e)
+        token_id = context.get('subject_token_id')
+        self.token_provider_api.check_v3_token(token_id)
 
-    @controller.protected
+    @controller.protected()
     def revoke_token(self, context):
         token_id = context.get('subject_token_id')
-        return self.token_controllers_ref.delete_token(context, token_id)
+        return self.token_provider_api.revoke_token(token_id)
 
-    @controller.protected
+    @controller.protected()
     def validate_token(self, context):
         token_id = context.get('subject_token_id')
-        self.check_token(context)
-        token_ref = self.token_api.get_token(context, token_id)
-        token_data = token_factory.recreate_token_data(
-            context,
-            token_ref.get('token_data'),
-            token_ref['expires'],
-            token_ref.get('user'),
-            token_ref.get('tenant'))
-        return token_factory.render_token_data_response(token_id, token_data)
+        token_data = self.token_provider_api.validate_v3_token(token_id)
+        return render_token_data_response(token_id, token_data)
 
-    @controller.protected
+    @controller.protected()
     def revocation_list(self, context, auth=None):
         return self.token_controllers_ref.revocation_list(context, auth)
+
+
+#FIXME(gyee): not sure if it belongs here or keystone.common. Park it here
+# for now.
+def render_token_data_response(token_id, token_data, created=False):
+    """Render token data HTTP response.
+
+    Stash token ID into the X-Subject-Token header.
+
+    """
+    headers = [('X-Subject-Token', token_id)]
+
+    if created:
+        status = (201, 'Created')
+    else:
+        status = (200, 'OK')
+
+    return wsgi.render_response(body=token_data,
+                                status=status, headers=headers)
