@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2013 OpenStack Foundation
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -15,13 +17,14 @@
 import functools
 import os
 
-from oslo_log import log
+from keystone.common import config
+from keystone.openstack.common import log as logging
+
+CONF = config.CONF
+LOG = logging.getLogger(__name__)
 
 
-LOG = log.getLogger(__name__)
-
-
-__all__ = ('Server', 'httplib', 'subprocess')
+__all__ = ['Server', 'httplib', 'subprocess']
 
 _configured = False
 
@@ -47,7 +50,7 @@ def configure_once(name):
                     raise SystemError("Environment has already been "
                                       "configured as %s" % _configured)
 
-            LOG.debug("Environment configured as: %s", name)
+            LOG.info(_("Environment configured as: %s"), name)
             _configured = name
             return func(*args, **kwargs)
 
@@ -67,7 +70,6 @@ def use_eventlet(monkeypatch_thread=None):
     import eventlet
     from eventlet.green import httplib as _httplib
     from eventlet.green import subprocess as _subprocess
-
     from keystone.common.environment import eventlet_server
 
     if monkeypatch_thread is None:
@@ -94,9 +96,8 @@ def use_eventlet(monkeypatch_thread=None):
 def use_stdlib():
     global httplib, subprocess
 
-    import six.moves.http_client as _httplib
-    import subprocess as _subprocess  # nosec : This is used in .federation.idp
-    # and .common.openssl. See there.
+    import httplib as _httplib
+    import subprocess as _subprocess
 
     httplib = _httplib
     subprocess = _subprocess
