@@ -1,6 +1,6 @@
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 
-# Copyright 2012 OpenStack LLC
+# Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -22,20 +22,23 @@ import sqlalchemy.engine.url
 from sqlalchemy.exc import DisconnectionError
 from sqlalchemy.ext import declarative
 import sqlalchemy.orm
+from sqlalchemy.orm.attributes import InstrumentedAttribute
 import sqlalchemy.pool
 from sqlalchemy import types as sql_types
-from sqlalchemy.orm.attributes import InstrumentedAttribute
 
-from keystone.common import logging
 from keystone import config
 from keystone import exception
+from keystone.openstack.common.db.sqlalchemy import models
 from keystone.openstack.common import jsonutils
+from keystone.openstack.common import log as logging
 
 
+LOG = logging.getLogger(__name__)
 CONF = config.CONF
 
-# maintain a single engine reference for sqlite in-memory
+# maintain a single engine reference for sqlalchemy engine
 GLOBAL_ENGINE = None
+GLOBAL_ENGINE_CALLBACKS = set()
 
 
 ModelBase = declarative.declarative_base()
@@ -43,14 +46,18 @@ ModelBase = declarative.declarative_base()
 
 # For exporting to other modules
 Column = sql.Column
+Index = sql.Index
 String = sql.String
 ForeignKey = sql.ForeignKey
 DateTime = sql.DateTime
 IntegrityError = sql.exc.IntegrityError
+OperationalError = sql.exc.OperationalError
 NotFound = sql.orm.exc.NoResultFound
 Boolean = sql.Boolean
 Text = sql.Text
 UniqueConstraint = sql.UniqueConstraint
+relationship = sql.orm.relationship
+joinedload = sql.orm.joinedload
 
 
 def initialize_decorator(init):
@@ -73,15 +80,10 @@ def initialize_decorator(init):
                 if isinstance(attr, InstrumentedAttribute):
                     column = attr.property.columns[0]
                     if isinstance(column.type, String):
+                        if not isinstance(v, unicode):
+                            v = str(v)
                         if column.type.length and \
-                                column.type.length < len(str(v)):
-                            #if signing.token_format == 'PKI', the id will
-                            #store it's public key which is very long.
-                            if config.CONF.signing.token_format == 'PKI' and \
-                                    self.__tablename__ == 'token' and \
-                                    k == 'id':
-                                continue
-
+                                column.type.length < len(v):
                             raise exception.StringLengthExceeded(
                                 string=v, type=k, length=column.type.length)
 
@@ -92,12 +94,48 @@ ModelBase.__init__ = initialize_decorator(ModelBase.__init__)
 
 
 def set_global_engine(engine):
+    """Set the global engine.
+
+    This sets the current global engine, which is returned by
+    Base.get_engine(allow_global_engine=True).
+
+    When the global engine is changed, all of the callbacks registered via
+    register_global_engine_callback since the last time set_global_engine was
+    changed are called. The callback functions are invoked with no arguments.
+
+    """
+
     global GLOBAL_ENGINE
+    global GLOBAL_ENGINE_CALLBACKS
+
+    if engine is GLOBAL_ENGINE:
+        # It's the same engine so nothing to do.
+        return
+
     GLOBAL_ENGINE = engine
 
+    cbs = GLOBAL_ENGINE_CALLBACKS
+    GLOBAL_ENGINE_CALLBACKS = set()
+    for cb in cbs:
+        try:
+            cb()
+        except Exception:
+            LOG.exception(_("Global engine callback raised."))
+            # Just logging the exception so can process other callbacks.
 
-def get_global_engine():
-    return GLOBAL_ENGINE
+
+def register_global_engine_callback(cb_fn):
+    """Register a function to be called when the global engine is set.
+
+    Note that the callback will be called only once or not at all, so to get
+    called each time the global engine is changed the function must be
+    re-registered.
+
+    """
+
+    global GLOBAL_ENGINE_CALLBACKS
+
+    GLOBAL_ENGINE_CALLBACKS.add(cb_fn)
 
 
 # Special Fields
@@ -112,7 +150,7 @@ class JsonBlob(sql_types.TypeDecorator):
         return jsonutils.loads(value)
 
 
-class DictBase(object):
+class DictBase(models.ModelBase):
     attributes = []
 
     @classmethod
@@ -141,47 +179,14 @@ class DictBase(object):
 
         return d
 
-    def __setitem__(self, key, value):
-        setattr(self, key, value)
-
     def __getitem__(self, key):
+        if key in self.extra:
+            return self.extra[key]
         return getattr(self, key)
 
-    def get(self, key, default=None):
-        return getattr(self, key, default)
 
-    def __iter__(self):
-        self._i = iter(sqlalchemy.orm.object_mapper(self).columns)
-        return self
-
-    def next(self):
-        n = self._i.next().name
-        return n
-
-    def update(self, values):
-        """Make the model object behave like a dict."""
-        for k, v in values.iteritems():
-            setattr(self, k, v)
-
-    def iteritems(self):
-        """Make the model object behave like a dict.
-
-        Includes attributes from joins.
-
-        """
-        return dict([(k, getattr(self, k)) for k in self])
-        #local = dict(self)
-        #joined = dict([(k, v) for k, v in self.__dict__.iteritems()
-        #               if not k[0] == '_'])
-        #local.update(joined)
-        #return local.iteritems()
-
-
-class MySQLPingListener(object):
-
-    """
-    Ensures that MySQL connections checked out of the
-    pool are alive.
+def mysql_on_checkout(dbapi_conn, connection_rec, connection_proxy):
+    """Ensures that MySQL connections checked out of the pool are alive.
 
     Borrowed from:
     http://groups.google.com/group/sqlalchemy/msg/a4ce563d802c929f
@@ -195,16 +200,29 @@ class MySQLPingListener(object):
 
     from http://dev.mysql.com/doc/refman/5.6/en/error-messages-client.html
     """
+    try:
+        dbapi_conn.cursor().execute('select 1')
+    except dbapi_conn.OperationalError as e:
+        if e.args[0] in (2006, 2013, 2014, 2045, 2055):
+            LOG.warn(_('Got mysql server has gone away: %s'), e)
+            raise DisconnectionError("Database server went away")
+        else:
+            raise
 
-    def checkout(self, dbapi_con, con_record, con_proxy):
-        try:
-            dbapi_con.cursor().execute('select 1')
-        except dbapi_con.OperationalError as e:
-            if e.args[0] in (2006, 2013, 2014, 2045, 2055):
-                logging.warn(_('Got mysql server has gone away: %s'), e)
-                raise DisconnectionError("Database server went away")
-            else:
-                raise
+
+def db2_on_checkout(engine, dbapi_conn, connection_rec, connection_proxy):
+    """Ensures that DB2 connections checked out of the pool are alive."""
+
+    cursor = dbapi_conn.cursor()
+    try:
+        cursor.execute('select 1 from (values (1)) AS t1')
+    except Exception as e:
+        is_disconnect = engine.dialect.is_disconnect(e, dbapi_conn, cursor)
+        if is_disconnect:
+            LOG.warn(_('Got database server has gone away: %s'), e)
+            raise DisconnectionError("Database server went away")
+        else:
+            raise
 
 
 # Backends
@@ -214,10 +232,12 @@ class Base(object):
 
     def get_session(self, autocommit=True, expire_on_commit=False):
         """Return a SQLAlchemy session."""
-        self._engine = self._engine or self.get_engine()
-        self._sessionmaker = self._sessionmaker or self.get_sessionmaker(
-            self._engine)
-        return self._sessionmaker()
+        if not self._engine:
+            self._engine = self.get_engine()
+            self._sessionmaker = self.get_sessionmaker(self._engine)
+            register_global_engine_callback(self.clear_engine)
+        return self._sessionmaker(autocommit=autocommit,
+                                  expire_on_commit=expire_on_commit)
 
     def get_engine(self, allow_global_engine=True):
         """Return a SQLAlchemy engine.
@@ -238,19 +258,30 @@ class Base(object):
 
             if 'sqlite' in connection_dict.drivername:
                 engine_config['poolclass'] = sqlalchemy.pool.StaticPool
-            elif 'mysql' in connection_dict.drivername:
-                engine_config['listeners'] = [MySQLPingListener()]
 
-            return sql.create_engine(CONF.sql.connection, **engine_config)
+            engine = sql.create_engine(CONF.sql.connection, **engine_config)
 
-        engine = get_global_engine() or new_engine()
+            if engine.name == 'mysql':
+                sql.event.listen(engine, 'checkout', mysql_on_checkout)
+            elif engine.name == 'ibm_db_sa':
+                callback = functools.partial(db2_on_checkout, engine)
+                sql.event.listen(engine, 'checkout', callback)
+
+            return engine
+
+        if not allow_global_engine:
+            return new_engine()
+
+        if GLOBAL_ENGINE:
+            return GLOBAL_ENGINE
+
+        engine = new_engine()
 
         # auto-build the db to support wsgi server w/ in-memory backend
-        if allow_global_engine and CONF.sql.connection == 'sqlite://':
+        if CONF.sql.connection == 'sqlite://':
             ModelBase.metadata.create_all(bind=engine)
 
-        if allow_global_engine:
-            set_global_engine(engine)
+        set_global_engine(engine)
 
         return engine
 
@@ -262,6 +293,10 @@ class Base(object):
             autocommit=autocommit,
             expire_on_commit=expire_on_commit)
 
+    def clear_engine(self):
+        self._engine = None
+        self._sessionmaker = None
+
 
 def handle_conflicts(type='object'):
     """Converts IntegrityError into HTTP 409 Conflict."""
@@ -270,7 +305,7 @@ def handle_conflicts(type='object'):
         def wrapper(*args, **kwargs):
             try:
                 return method(*args, **kwargs)
-            except IntegrityError as e:
+            except (IntegrityError, OperationalError) as e:
                 raise exception.Conflict(type=type, details=str(e.orig))
         return wrapper
     return decorator
