@@ -1,11 +1,24 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright 2013 OpenStack Foundation
+#
+#    Licensed under the Apache License, Version 2.0 (the "License"); you may
+#    not use this file except in compliance with the License. You may obtain
+#    a copy of the License at
+#
+#         http://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#    License for the specific language governing permissions and limitations
+#    under the License.
+
 import json
-import uuid
 
 import sqlalchemy as sql
-from sqlalchemy import orm
 
 from keystone import config
-from keystone import exception
 
 
 CONF = config.CONF
@@ -15,9 +28,9 @@ def upgrade(migrate_engine):
     meta = sql.MetaData()
     meta.bind = migrate_engine
 
-    user_table = sql.Table('user', meta, autoload=True)
+    sql.Table('user', meta, autoload=True)
+    sql.Table('project', meta, autoload=True)
     role_table = sql.Table('role', meta, autoload=True)
-    project_table = sql.Table('project', meta, autoload=True)
 
     user_project_role_table = sql.Table(
         'user_project_metadata',
@@ -59,8 +72,8 @@ def downgrade(migrate_engine):
     meta = sql.MetaData()
     meta.bind = migrate_engine
 
-    user_table = sql.Table('user', meta, autoload=True)
-    project_table = sql.Table('project', meta, autoload=True)
+    sql.Table('user', meta, autoload=True)
+    sql.Table('project', meta, autoload=True)
 
     user_project_membership_table = sql.Table(
         'user_project_membership',
@@ -87,9 +100,9 @@ def downgrade(migrate_engine):
         if 'roles' in membership:
             roles = membership['roles']
             if config.CONF.member_role_id in roles:
-                ins = (user_project_membership_table.insert()
-                       .values(user_id=membership.user_id,
-                               tenant_id=membership.project_id))
+                user_project_membership_table.insert().values(
+                    user_id=membership.user_id,
+                    tenant_id=membership.project_id)
     session.close()
     role_table = sql.Table('role', meta, autoload=True)
     conn = migrate_engine.connect()
