@@ -1,3 +1,19 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright 2013 OpenStack Foundation
+#
+#    Licensed under the Apache License, Version 2.0 (the "License"); you may
+#    not use this file except in compliance with the License. You may obtain
+#    a copy of the License at
+#
+#         http://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#    License for the specific language governing permissions and limitations
+#    under the License.
+
 import json
 
 import sqlalchemy as sql
@@ -30,6 +46,7 @@ def upgrade(migrate_engine):
                 endpoint_table.c.extra: json.dumps(extra),
                 endpoint_table.c.legacy_endpoint_id: legacy_endpoint_id})
             migrate_engine.execute(q)
+    session.close()
 
 
 def downgrade(migrate_engine):
@@ -50,3 +67,4 @@ def downgrade(migrate_engine):
                 endpoint_table.c.extra: json.dumps(extra),
                 endpoint_table.c.legacy_endpoint_id: None})
             migrate_engine.execute(q)
+    session.close()
