@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2013 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -15,14 +17,10 @@
 """WSGI Routers for the Credentials service."""
 
 from keystone.common import router
-from keystone.common import wsgi
 from keystone.credential import controllers
 
 
-class Routers(wsgi.RoutersBase):
-
-    def append_v3_routers(self, mapper, routers):
-        routers.append(
-            router.Router(controllers.CredentialV3(),
-                          'credentials', 'credential',
-                          resource_descriptions=self.v3_resources))
+def append_v3_routers(mapper, routers):
+    routers.append(
+        router.Router(controllers.CredentialV3(),
+                      'credentials', 'credential'))
