@@ -1,6 +1,6 @@
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 
-# Copyright 2012 OpenStack LLC
+# Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -16,6 +16,7 @@
 """WSGI Routers for the Identity service."""
 from keystone.common import router
 from keystone.common import wsgi
+from keystone import config
 from keystone.identity import controllers
 
 
@@ -107,10 +108,6 @@ def append_v3_routers(mapper, routers):
                    action='list_groups_for_user',
                    conditions=dict(method=['GET']))
 
-    routers.append(
-        router.Router(controllers.CredentialV3(),
-                      'credentials', 'credential'))
-
     role_controller = controllers.RoleV3()
     routers.append(router.Router(role_controller, 'roles', 'role'))
     mapper.connect('/projects/{project_id}/users/{user_id}/roles/{role_id}',
@@ -177,3 +174,48 @@ def append_v3_routers(mapper, routers):
                    controller=role_controller,
                    action='revoke_grant',
                    conditions=dict(method=['DELETE']))
+
+    if config.CONF.os_inherit.enabled:
+        mapper.connect(('/OS-INHERIT/domains/{domain_id}/users/{user_id}'
+                        '/roles/{role_id}/inherited_to_projects'),
+                       controller=role_controller,
+                       action='create_grant',
+                       conditions=dict(method=['PUT']))
+        mapper.connect(('/OS-INHERIT/domains/{domain_id}/groups/{group_id}'
+                        '/roles/{role_id}/inherited_to_projects'),
+                       controller=role_controller,
+                       action='create_grant',
+                       conditions=dict(method=['PUT']))
+        mapper.connect(('/OS-INHERIT/domains/{domain_id}/users/{user_id}'
+                        '/roles/{role_id}/inherited_to_projects'),
+                       controller=role_controller,
+                       action='check_grant',
+                       conditions=dict(method=['HEAD']))
+        mapper.connect(('/OS-INHERIT/domains/{domain_id}/groups/{group_id}'
+                        '/roles/{role_id}/inherited_to_projects'),
+                       controller=role_controller,
+                       action='check_grant',
+                       conditions=dict(method=['HEAD']))
+        mapper.connect(('/OS-INHERIT/domains/{domain_id}/users/{user_id}'
+                        '/roles/inherited_to_projects'),
+                       controller=role_controller,
+                       action='list_grants',
+                       conditions=dict(method=['GET']))
+        mapper.connect(('/OS-INHERIT/domains/{domain_id}/groups/{group_id}'
+                        '/roles/inherited_to_projects'),
+                       controller=role_controller,
+                       action='list_grants',
+                       conditions=dict(method=['GET']))
+        mapper.connect(('/OS-INHERIT/domains/{domain_id}/users/{user_id}'
+                        '/roles/{role_id}/inherited_to_projects'),
+                       controller=role_controller,
+                       action='revoke_grant',
+                       conditions=dict(method=['DELETE']))
+        mapper.connect(('/OS-INHERIT/domains/{domain_id}/groups/{group_id}'
+                        '/roles/{role_id}/inherited_to_projects'),
+                       controller=role_controller,
+                       action='revoke_grant',
+                       conditions=dict(method=['DELETE']))
+    routers.append(
+        router.Router(controllers.RoleAssignmentV3(),
+                      'role_assignments', 'role_assignment'))
