@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,13 +14,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 from keystone.common import router
-from keystone.common import wsgi
 from keystone.policy import controllers
 
 
-class Routers(wsgi.RoutersBase):
-
-    def append_v3_routers(self, mapper, routers):
-        policy_controller = controllers.PolicyV3()
-        routers.append(router.Router(policy_controller, 'policies', 'policy',
-                                     resource_descriptions=self.v3_resources))
+def append_v3_routers(mapper, routers):
+    policy_controller = controllers.PolicyV3()
+    routers.append(router.Router(policy_controller, 'policies', 'policy'))
