@@ -1,6 +1,6 @@
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 
-# Copyright 2012 OpenStack LLC
+# Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,31 +18,38 @@ import copy
 
 from keystone.common import kvs
 from keystone import exception
+from keystone.openstack.common import log as logging
 from keystone.openstack.common import timeutils
 from keystone import token
 
+LOG = logging.getLogger(__name__)
+
 
 class Token(kvs.Base, token.Driver):
+    """kvs backend for tokens is deprecated.
+
+    Deprecated in Havana and will be removed in Icehouse, as this backend
+    is not production grade.
+    """
+
+    def __init__(self, *args, **kw):
+        super(Token, self).__init__(*args, **kw)
+        LOG.warn(_("kvs token backend is DEPRECATED. Use "
+                   "keystone.token.backends.sql or "
+                   "keystone.token.backend.memcache instead."))
 
     # Public interface
     def get_token(self, token_id):
-        token_id = token.unique_id(token_id)
         try:
             ref = self.db.get('token-%s' % token_id)
-        except exception.NotFound:
-            raise exception.TokenNotFound(token_id=token_id)
-        now = timeutils.utcnow()
-        expiry = ref['expires']
-        if expiry is None:
-            raise exception.TokenNotFound(token_id=token_id)
-        if expiry > now:
             return copy.deepcopy(ref)
-        else:
+        except Exception:
+            # On any issues here, Token is not found.
             raise exception.TokenNotFound(token_id=token_id)
 
     def create_token(self, token_id, data):
-        token_id = token.unique_id(token_id)
         data_copy = copy.deepcopy(data)
+        data_copy['id'] = token_id
         if not data_copy.get('expires'):
             data_copy['expires'] = token.default_expire_time()
         if not data_copy.get('user_id'):
@@ -51,7 +58,6 @@ class Token(kvs.Base, token.Driver):
         return copy.deepcopy(data_copy)
 
     def delete_token(self, token_id):
-        token_id = token.unique_id(token_id)
         try:
             token_ref = self.get_token(token_id)
             self.db.delete('token-%s' % token_id)
@@ -74,11 +80,33 @@ class Token(kvs.Base, token.Driver):
         for token, ref in self.db.items():
             if not token.startswith('token-') or self.is_expired(now, ref):
                 continue
-            ref_trust_id = ref.get('trust_id')
             if self.trust_matches(trust_id, ref):
                 tokens.append(token.split('-', 1)[1])
         return tokens
 
+    def _consumer_matches(self, consumer_id, token_ref_dict):
+        if consumer_id is None:
+            return True
+        else:
+            if 'token_data' in token_ref_dict:
+                token_data = token_ref_dict.get('token_data')
+                if 'token' in token_data:
+                    token = token_data.get('token')
+                    oauth = token.get('OS-OAUTH1')
+                    if oauth and oauth.get('consumer_id') == consumer_id:
+                        return True
+            return False
+
+    def _list_tokens_for_consumer(self, consumer_id):
+        tokens = []
+        now = timeutils.utcnow()
+        for token, ref in self.db.items():
+            if not token.startswith('token-') or self.is_expired(now, ref):
+                continue
+            if self._consumer_matches(consumer_id, ref):
+                tokens.append(token.split('-', 1)[1])
+        return tokens
+
     def _list_tokens_for_user(self, user_id, tenant_id=None):
         def user_matches(user_id, ref):
             return ref.get('user') and ref['user'].get('id') == user_id
@@ -99,9 +127,12 @@ class Token(kvs.Base, token.Driver):
                         tokens.append(token.split('-', 1)[1])
         return tokens
 
-    def list_tokens(self, user_id, tenant_id=None, trust_id=None):
+    def list_tokens(self, user_id, tenant_id=None, trust_id=None,
+                    consumer_id=None):
         if trust_id:
             return self._list_tokens_for_trust(trust_id)
+        if consumer_id:
+            return self._list_tokens_for_consumer(consumer_id)
         else:
             return self._list_tokens_for_user(user_id, tenant_id)
 
@@ -115,3 +146,11 @@ class Token(kvs.Base, token.Driver):
             record['expires'] = token_ref['expires']
             tokens.append(record)
         return tokens
+
+    def flush_expired_tokens(self):
+        now = timeutils.utcnow()
+        for token, token_ref in self.db.items():
+            if not token.startswith('revoked-token-'):
+                continue
+            if self.is_expired(now, token_ref):
+                self.db.delete(token)
